==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/ta.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "லைட்பாக்ஸில் Gallary துப்புகள் நிர்வகி");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "கேலரி நிர்வகிக்க");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "முழு அளவு படத்தை அகலம்");
define('MANAGE_GALLERY_FULL_HEIGHT', "முழு அளவு பட உயரம்");
define('MANAGE_GALLERY_THUMB_WIDTH', "சிறு பட அகலம்");
define('MANAGE_GALLERY_THUMB_HEIGHT', "சிறு பட உயரம்");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "கட்டைவிரல் விகிதம் காத்தருளும்");
define('MANAGE_GALLERY_SHOW_TITLES', "தலைப்புகள் காட்டு");
define('MANAGE_GALLERY_DISABLE_SORT', "வரிசைப்படுத்த முடக்கு");
define('MANAGE_GALLERY_DELETE_IMAGE', "படத்தை நீக்கு");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "வரிசை ஒழுங்கு சேமிக்க");
define('MANAGE_GALLERY_PUBLISH_MSG', "வெளியிட &#39;அப்டேட்&#39; கிளிக் செய்யவும் <br /> உங்கள் பதிவேற்றிய.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "அனைத்து படங்களையும் மறுஅளவிடப்பட்ட மற்றும் அமைப்புகளை சேமிக்கப்பட்டுள்ளன.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "பிழை படங்களை மறு அல்லது அமைப்புகள் சேமிப்பு இருந்தது.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "உங்கள் படத்தை (கள்) பதிவேற்றம் செய்யப்பட்டுள்ளது.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "உங்கள் படத்தை (கள்) ஏற்றுவதில் பிழை இருந்தது.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்பு ஒரு படம் அல்ல.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்பு மிகவும் பெரியது.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "தலைப்பு சேமிக்கப்பட்டது.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "நீங்கள் படத்தை நீக்க வேண்டும் என்பதில் உறுதியாக இருக்கிறீர்களா");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "படத்தை நீக்கப்பட்டுவிட்டது.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "படத்தை நீக்குவதில் பிழை இருந்தது.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "அளவுருக்கள் சேமிப்பு மற்றும் மறு படங்கள், தயவு செய்து காத்திருக்கவும் ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "பதிவேற்றுகிறது, தயவுசெய்து காத்திருக்கவும் ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "வரிசையைப் சேமிக்கப்படவில்லை என்பதையும். நீங்கள் வரிசையைப் சேமிக்க வேண்டுமா?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "படத்தை வரிசையைப் சேமிக்கப்பட்டது.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "படத்தை வகையான சேமிப்பு பிழை இருந்தது.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ta.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "லைட்பாக்ஸில் Gallary துப்புகள் நிர்வகி");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "கேலரி நிர்வகிக்க");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "முழு அளவு படத்தை அகலம்");
define('MANAGE_GALLERY_FULL_HEIGHT', "முழு அளவு பட உயரம்");
define('MANAGE_GALLERY_THUMB_WIDTH', "சிறு பட அகலம்");
define('MANAGE_GALLERY_THUMB_HEIGHT', "சிறு பட உயரம்");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "கட்டைவிரல் விகிதம் காத்தருளும்");
define('MANAGE_GALLERY_SHOW_TITLES', "தலைப்புகள் காட்டு");
define('MANAGE_GALLERY_DISABLE_SORT', "வரிசைப்படுத்த முடக்கு");
define('MANAGE_GALLERY_DELETE_IMAGE', "படத்தை நீக்கு");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "வரிசை ஒழுங்கு சேமிக்க");
define('MANAGE_GALLERY_PUBLISH_MSG', "வெளியிட &#39;அப்டேட்&#39; கிளிக் செய்யவும் <br /> உங்கள் பதிவேற்றிய.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "அனைத்து படங்களையும் மறுஅளவிடப்பட்ட மற்றும் அமைப்புகளை சேமிக்கப்பட்டுள்ளன.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "பிழை படங்களை மறு அல்லது அமைப்புகள் சேமிப்பு இருந்தது.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "உங்கள் படத்தை (கள்) பதிவேற்றம் செய்யப்பட்டுள்ளது.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "உங்கள் படத்தை (கள்) ஏற்றுவதில் பிழை இருந்தது.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்பு ஒரு படம் அல்ல.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்பு மிகவும் பெரியது.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "தலைப்பு சேமிக்கப்பட்டது.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "நீங்கள் படத்தை நீக்க வேண்டும் என்பதில் உறுதியாக இருக்கிறீர்களா");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "படத்தை நீக்கப்பட்டுவிட்டது.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "படத்தை நீக்குவதில் பிழை இருந்தது.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "அளவுருக்கள் சேமிப்பு மற்றும் மறு படங்கள், தயவு செய்து காத்திருக்கவும் ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "பதிவேற்றுகிறது, தயவுசெய்து காத்திருக்கவும் ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "வரிசையைப் சேமிக்கப்படவில்லை என்பதையும். நீங்கள் வரிசையைப் சேமிக்க வேண்டுமா?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "படத்தை வரிசையைப் சேமிக்கப்பட்டது.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "படத்தை வகையான சேமிப்பு பிழை இருந்தது.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்பு &#39;upload_max_filesize&#39; அல்லது &#39;post_max_size&#39; PHP அமைப்புகளை விட பெரியது. இந்த வரம்புகளை அதிகரிக்க உங்கள் கணினி நிர்வாகியைத் தொடர்பு கொள்ளுங்கள்.");
?>
